@@ -73,8 +73,8 @@ class ImageDataController(object):
             try:
                 image_repo.save(image)
                 image.set_data(data, size)
-                image_repo.save(image)
-            except exception.NotFound as e:
+                image_repo.save(image, from_state='saving')
+            except (exception.NotFound, exception.Conflict) as e:
                 msg = (_("Image %(id)s could not be found after upload."
                          "The image may have been deleted during the upload: "
                          "%(error)s Cleaning up the chunks uploaded") %
@@ -152,6 +152,10 @@ class ImageDataController(object):
             raise webob.exc.HTTPServiceUnavailable(explanation=msg,
                                                    request=req)
 
+        except webob.exc.HTTPGone as e:
+            with excutils.save_and_reraise_exception():
+                LOG.error(_LE("Failed to upload image data due to HTTP error"))
+
         except webob.exc.HTTPError as e:
             with excutils.save_and_reraise_exception():
                 LOG.error(_LE("Failed to upload image data due to HTTP error"))
