@@ -14,30 +14,30 @@
 #    under the License.
 
 import copy
-import json
+import six
 import webob
 
+import glance_store
+
 from glance.api import policy
 from glance.common import exception
 from glance.common import utils
 from glance.common import wsgi
 import glance.db
-import glance.domain
 import glance.gateway
 import glance.notifier
+from glance.openstack.common import jsonutils
 from glance.openstack.common import timeutils
 import glance.schema
-import glance.store
 
 
 class ImageMembersController(object):
     def __init__(self, db_api=None, policy_enforcer=None, notifier=None,
                  store_api=None):
         self.db_api = db_api or glance.db.get_api()
-        self.db_api.setup_db_env()
         self.policy = policy_enforcer or policy.Enforcer()
         self.notifier = notifier or glance.notifier.Notifier()
-        self.store_api = store_api or glance.store
+        self.store_api = store_api or glance_store
         self.gateway = glance.gateway.Gateway(self.db_api, self.store_api,
                                               self.notifier, self.policy)
 
@@ -65,15 +65,17 @@ class ImageMembersController(object):
             member_repo = image.get_member_repo()
             new_member = image_member_factory.new_image_member(image,
                                                                member_id)
-            member = member_repo.add(new_member)
+            member_repo.add(new_member)
 
-            return member
+            return new_member
         except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=unicode(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            raise webob.exc.HTTPForbidden(explanation=unicode(e))
+            raise webob.exc.HTTPForbidden(explanation=e.msg)
         except exception.Duplicate as e:
-            raise webob.exc.HTTPConflict(explanation=unicode(e))
+            raise webob.exc.HTTPConflict(explanation=e.msg)
+        except exception.ImageMemberLimitExceeded as e:
+            raise webob.exc.HTTPRequestEntityTooLarge(explanation=e.msg)
 
     @utils.mutating
     def update(self, req, image_id, member_id, status):
@@ -97,14 +99,15 @@ class ImageMembersController(object):
             member_repo = image.get_member_repo()
             member = member_repo.get(member_id)
             member.status = status
-            member = member_repo.save(member)
+            member_repo.save(member)
             return member
         except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=unicode(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            raise webob.exc.HTTPForbidden(explanation=unicode(e))
+            raise webob.exc.HTTPForbidden(explanation=e.msg)
         except ValueError as e:
-            raise webob.exc.HTTPBadRequest(explanation=unicode(e))
+            raise webob.exc.HTTPBadRequest(explanation=
+                                           utils.exception_to_str(e))
 
     def index(self, req, image_id):
         """
@@ -132,9 +135,32 @@ class ImageMembersController(object):
                 members.append(member)
             return dict(members=members)
         except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=unicode(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            raise webob.exc.HTTPForbidden(explanation=unicode(e))
+            raise webob.exc.HTTPForbidden(explanation=e.msg)
+
+    def show(self, req, image_id, member_id):
+        """
+        Returns the membership of the tenant wrt to the image_id specified.
+
+        :param req: the Request object coming from the wsgi layer
+        :param image_id: The image identifier
+        :retval The response body is a mapping of the following form::
+
+            {'member_id': <MEMBER>,
+             'image_id': <IMAGE>,
+             'status': <MEMBER_STATUS>
+             'created_at': ..,
+             'updated_at': ..}
+        """
+        image_repo = self.gateway.get_repo(req.context)
+        try:
+            image = image_repo.get(image_id)
+            member_repo = image.get_member_repo()
+            member = member_repo.get(member_id)
+            return member
+        except (exception.NotFound, exception.Forbidden) as e:
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
 
     @utils.mutating
     def delete(self, req, image_id, member_id):
@@ -150,9 +176,9 @@ class ImageMembersController(object):
             member_repo.remove(member)
             return webob.Response(body='', status=204)
         except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=unicode(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            raise webob.exc.HTTPForbidden(explanation=unicode(e))
+            raise webob.exc.HTTPForbidden(explanation=e.msg)
 
 
 class RequestDeserializer(wsgi.JSONRequestDeserializer):
@@ -209,14 +235,14 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
 
     def create(self, response, image_member):
         image_member_view = self._format_image_member(image_member)
-        body = json.dumps(image_member_view, ensure_ascii=False)
-        response.unicode_body = unicode(body)
+        body = jsonutils.dumps(image_member_view, ensure_ascii=False)
+        response.unicode_body = six.text_type(body)
         response.content_type = 'application/json'
 
     def update(self, response, image_member):
         image_member_view = self._format_image_member(image_member)
-        body = json.dumps(image_member_view, ensure_ascii=False)
-        response.unicode_body = unicode(body)
+        body = jsonutils.dumps(image_member_view, ensure_ascii=False)
+        response.unicode_body = six.text_type(body)
         response.content_type = 'application/json'
 
     def index(self, response, image_members):
@@ -227,8 +253,14 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
             image_members_view.append(image_member_view)
         totalview = dict(members=image_members_view)
         totalview['schema'] = '/v2/schemas/members'
-        body = json.dumps(totalview, ensure_ascii=False)
-        response.unicode_body = unicode(body)
+        body = jsonutils.dumps(totalview, ensure_ascii=False)
+        response.unicode_body = six.text_type(body)
+        response.content_type = 'application/json'
+
+    def show(self, response, image_member):
+        image_member_view = self._format_image_member(image_member)
+        body = jsonutils.dumps(image_member_view, ensure_ascii=False)
+        response.unicode_body = six.text_type(body)
         response.content_type = 'application/json'
 
 
