@@ -37,15 +37,17 @@ import eventlet.wsgi
 from oslo.config import cfg
 import routes
 import routes.middleware
+import six
 import webob.dec
 import webob.exc
 from webob import multidict
 
 from glance.common import exception
 from glance.common import utils
-from glance.openstack.common import gettextutils
+from glance import i18n
 from glance.openstack.common import jsonutils
 import glance.openstack.common.log as logging
+from glance.openstack.common import processutils
 
 
 bind_opts = [
@@ -73,9 +75,10 @@ socket_opts = [
 ]
 
 eventlet_opts = [
-    cfg.IntOpt('workers', default=1,
+    cfg.IntOpt('workers', default=processutils.get_worker_count(),
                help=_('The number of child process workers that will be '
-                      'created to service API requests.')),
+                      'created to service requests. The default will be '
+                      'equal to the number of CPUs available.')),
     cfg.StrOpt('eventlet_hub', default='poll',
                help=_('Name of eventlet hub to use. Traditionally, we have '
                       'only supported \'poll\', however \'selects\' may be '
@@ -88,11 +91,21 @@ eventlet_opts = [
                       'Keystone v3 API with big service catalogs')),
 ]
 
+profiler_opts = [
+    cfg.BoolOpt("enabled", default=False,
+                help=_('If False fully disable profiling feature.')),
+    cfg.BoolOpt("trace_sqlalchemy", default=False,
+                help=_("If False doesn't trace SQL requests."))
+]
+
+
+LOG = logging.getLogger(__name__)
 
 CONF = cfg.CONF
 CONF.register_opts(bind_opts)
 CONF.register_opts(socket_opts)
 CONF.register_opts(eventlet_opts)
+CONF.register_opts(profiler_opts, group="profiler")
 
 
 def get_bind_addr(default_port=None):
@@ -182,6 +195,15 @@ def get_socket(default_port):
     return sock
 
 
+def set_eventlet_hub():
+    try:
+        eventlet.hubs.use_hub(cfg.CONF.eventlet_hub)
+    except Exception:
+        msg = _("eventlet '%s' hub is not available on this platform")
+        raise exception.WorkerCreationFailure(
+            reason=msg % cfg.CONF.eventlet_hub)
+
+
 class Server(object):
     """Server class to manage multiple WSGI sockets and applications."""
 
@@ -275,7 +297,7 @@ class Server(object):
                 break
         eventlet.greenio.shutdown_safe(self.sock)
         self.sock.close()
-        self.logger.debug(_('Exited'))
+        self.logger.debug('Exited')
 
     def wait(self):
         """Wait until all servers have completed running."""
@@ -312,12 +334,6 @@ class Server(object):
                                            cfg.CONF.pydev_worker_debug_port)
 
         eventlet.wsgi.HttpProtocol.default_request_version = "HTTP/1.0"
-        try:
-            eventlet.hubs.use_hub(cfg.CONF.eventlet_hub)
-        except Exception:
-            msg = _("eventlet '%s' hub is not available on this platform")
-            raise exception.WorkerCreationFailure(
-                reason=msg % cfg.CONF.eventlet_hub)
         self.pool = self.create_pool()
         try:
             eventlet.wsgi.server(self.sock,
@@ -398,7 +414,7 @@ class Debug(Middleware):
         resp = req.get_response(self.application)
 
         print(("*" * 40) + " RESPONSE HEADERS")
-        for (key, value) in resp.headers.iteritems():
+        for (key, value) in six.iteritems(resp.headers):
             print(key, "=", value)
         print('')
 
@@ -433,6 +449,14 @@ class APIMapper(routes.Mapper):
         return routes.Mapper.routematch(self, url, environ)
 
 
+class RejectMethodController(object):
+    def reject(self, req, allowed_methods, *args, **kwargs):
+        LOG.debug("The method %s is not allowed for this resource" %
+                  req.environ['REQUEST_METHOD'])
+        raise webob.exc.HTTPMethodNotAllowed(
+            headers=[('Allow', allowed_methods)])
+
+
 class Router(object):
     """
     WSGI middleware that maps incoming requests to WSGI apps.
@@ -475,7 +499,7 @@ class Router(object):
     def __call__(self, req):
         """
         Route the incoming request to a controller based on self.map.
-        If no match, return a 404.
+        If no match, return either a 404(Not Found) or 501(Not Implemented).
         """
         return self._router
 
@@ -484,12 +508,17 @@ class Router(object):
     def _dispatch(req):
         """
         Called by self._router after matching the incoming request to a route
-        and putting the information into req.environ.  Either returns 404
-        or the routed WSGI app's response.
+        and putting the information into req.environ.  Either returns 404,
+        501, or the routed WSGI app's response.
         """
         match = req.environ['wsgiorg.routing_args'][1]
         if not match:
-            return webob.exc.HTTPNotFound()
+            implemented_http_methods = ['GET', 'HEAD', 'POST', 'PUT',
+                                        'DELETE', 'PATCH']
+            if req.environ['REQUEST_METHOD'] not in implemented_http_methods:
+                return webob.exc.HTTPNotImplemented()
+            else:
+                return webob.exc.HTTPNotFound()
         app = match['controller']
         return app
 
@@ -523,9 +552,19 @@ class Request(webob.Request):
         """
         if not self.accept_language:
             return None
-        langs = gettextutils.get_available_languages('glance')
+        langs = i18n.get_available_languages('glance')
         return self.accept_language.best_match(langs)
 
+    def get_content_range(self):
+        """Return the `Range` in a request."""
+        range_str = self.headers.get('Content-Range')
+        if range_str is not None:
+            range_ = webob.byterange.ContentRange.parse(range_str)
+            if range_ is None:
+                msg = _('Malformed Content-Range header: %s') % range_str
+                raise webob.exc.HTTPBadRequest(explanation=msg)
+            return range_
+
 
 class JSONRequestDeserializer(object):
     def has_body(self, request):
@@ -593,10 +632,10 @@ def translate_exception(req, e):
     locale = req.best_match_language()
 
     if isinstance(e, webob.exc.HTTPError):
-        e.explanation = gettextutils.translate(e.explanation, locale)
-        e.detail = gettextutils.translate(e.detail, locale)
+        e.explanation = i18n.translate(e.explanation, locale)
+        e.detail = i18n.translate(e.detail, locale)
         if getattr(e, 'body_template', None):
-            e.body_template = gettextutils.translate(e.body_template, locale)
+            e.body_template = i18n.translate(e.body_template, locale)
     return e
 
 
