@@ -12,9 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_db import exception as db_exc
-from oslo_db.sqlalchemy.utils import paginate_query
-from oslo_log import log as logging
+from oslo.db import exception as db_exc
+from oslo.db.sqlalchemy.utils import paginate_query
 import sqlalchemy.exc as sa_exc
 from sqlalchemy import or_
 import sqlalchemy.orm as sa_orm
@@ -22,9 +21,11 @@ import sqlalchemy.orm as sa_orm
 from glance.common import exception as exc
 import glance.db.sqlalchemy.metadef_api as metadef_api
 from glance.db.sqlalchemy import models_metadef as models
-from glance.i18n import _
+from glance import i18n
+import glance.openstack.common.log as os_logging
 
-LOG = logging.getLogger(__name__)
+LOG = os_logging.getLogger(__name__)
+_LW = i18n._LW
 
 
 def _is_namespace_visible(context, namespace, status=None):
@@ -55,7 +56,7 @@ def _is_namespace_visible(context, namespace, status=None):
 def _select_namespaces_query(context, session):
     """Build the query to get all namespaces based on the context"""
 
-    LOG.debug("context.is_admin=%(is_admin)s; context.owner=%(owner)s",
+    LOG.debug("context.is_admin=%(is_admin)s; context.owner=%(owner)s" %
               {'is_admin': context.is_admin, 'owner': context.owner})
 
     # If admin, return everything.
@@ -77,23 +78,24 @@ def _select_namespaces_query(context, session):
         return query
 
 
-def _get(context, session, namespace_id):
+def _get(context, namespace_id, session):
     """Get a namespace by id, raise if not found"""
 
     try:
-        query = session.query(models.MetadefNamespace).filter_by(
-            id=namespace_id)
+        query = session.query(models.MetadefNamespace)\
+            .filter_by(id=namespace_id)
         namespace_rec = query.one()
     except sa_orm.exc.NoResultFound:
-        msg = (_("Metadata definition namespace not found for id=%s")
-               % namespace_id)
-        LOG.warning(msg)
-        raise exc.MetadefNamespaceNotFound(msg)
+        LOG.warn(_LW("Metadata definition namespace not found for id=%s",
+                     namespace_id))
+        raise exc.MetadefRecordNotFound(record_type='namespace',
+                                        id=namespace_id)
 
     # Make sure they are allowed to view it.
-    if not _is_namespace_visible(context, namespace_rec.to_dict()):
-        LOG.debug("Forbidding request, metadata definition namespace=%s"
-                  " is not visible.", namespace_rec.namespace)
+    if not _is_namespace_visible(context, namespace_rec.as_dict()):
+        msg = ("Forbidding request, metadata definition namespace=%s"
+               " is not visible.") % namespace_rec.namespace
+        LOG.debug(msg)
         emsg = _("Forbidding request, metadata definition namespace=%s"
                  " is not visible.") % namespace_rec.namespace
         raise exc.MetadefForbidden(emsg)
@@ -101,23 +103,25 @@ def _get(context, session, namespace_id):
     return namespace_rec
 
 
-def _get_by_name(context, session, name):
+def _get_by_name(context, name, session):
     """Get a namespace by name, raise if not found"""
 
     try:
-        query = session.query(models.MetadefNamespace).filter_by(
-            namespace=name)
+        query = session.query(models.MetadefNamespace)\
+            .filter_by(namespace=name)
         namespace_rec = query.one()
     except sa_orm.exc.NoResultFound:
-        LOG.debug("Metadata definition namespace=%s was not found.", name)
+        msg = "Metadata definition namespace=%s was not found." % name
+        LOG.debug(msg)
         raise exc.MetadefNamespaceNotFound(namespace_name=name)
 
     # Make sure they are allowed to view it.
-    if not _is_namespace_visible(context, namespace_rec.to_dict()):
-        LOG.debug("Forbidding request, metadata definition namespace=%s"
-                  " is not visible.", name)
+    if not _is_namespace_visible(context, namespace_rec.as_dict()):
+        msg = ("Forbidding request, metadata definition namespace=%s"
+               " not visible." % name)
+        LOG.debug(msg)
         emsg = _("Forbidding request, metadata definition namespace=%s"
-                 " is not visible.") % name
+                 " not visible.") % name
         raise exc.MetadefForbidden(emsg)
 
     return namespace_rec
@@ -150,7 +154,7 @@ def _get_all(context, session, filters=None, marker=None,
 
     marker_namespace = None
     if marker is not None:
-        marker_namespace = _get(context, session, marker)
+        marker_namespace = _get(context, marker, session)
 
     sort_keys = ['created_at', 'id']
     sort_keys.insert(0, sort_key) if sort_key not in sort_keys else sort_keys
@@ -174,17 +178,15 @@ def _get_all_by_resource_types(context, session, filters, marker=None,
         session.query(models.MetadefResourceType)
         .join(models.MetadefResourceType.associations)
         .filter(models.MetadefResourceType.name.in_(resource_type_list))
-        .with_entities(
-            models.MetadefResourceType.name,
-            models.MetadefNamespaceResourceType.namespace_id,
-        )
+        .values(models.MetadefResourceType.name,
+                models.MetadefNamespaceResourceType.namespace_id)
     )
 
     namespace_id_list = []
     for name, namespace_id in db_recs:
         namespace_id_list.append(namespace_id)
 
-    if len(namespace_id_list) == 0:
+    if len(namespace_id_list) is 0:
         return []
 
     filters2 = filters
@@ -208,16 +210,16 @@ def get_all(context, session, marker=None, limit=None,
         namespaces = _get_all(
             context, session, filters, marker, limit, sort_key, sort_dir)
 
-    return [ns.to_dict() for ns in namespaces]
+    return map(lambda ns: ns.as_dict(), namespaces)
 
 
-def get(context, session, name):
+def get(context, name, session):
     """Get a namespace by name, raise if not found"""
-    namespace_rec = _get_by_name(context, session, name)
-    return namespace_rec.to_dict()
+    namespace_rec = _get_by_name(context, name, session)
+    return namespace_rec.as_dict()
 
 
-def create(context, session, values):
+def create(context, values, session):
     """Create a namespace, raise if namespace already exists."""
 
     namespace_name = values['namespace']
@@ -227,76 +229,79 @@ def create(context, session, values):
     try:
         namespace.save(session=session)
     except db_exc.DBDuplicateEntry:
-        LOG.debug("Can not create the metadata definition namespace."
-                  " Namespace=%s already exists.", namespace_name)
+        msg = ("Can not create the metadata definition namespace."
+               " Namespace=%s already exists.") % namespace_name
+        LOG.debug(msg)
         raise exc.MetadefDuplicateNamespace(
             namespace_name=namespace_name)
 
-    return namespace.to_dict()
+    return namespace.as_dict()
 
 
-def update(context, session, namespace_id, values):
+def update(context, namespace_id, values, session):
     """Update a namespace, raise if not found/visible or duplicate result"""
 
-    namespace_rec = _get(context, session, namespace_id)
+    namespace_rec = _get(context, namespace_id, session)
     metadef_api.utils.drop_protected_attrs(models.MetadefNamespace, values)
 
     try:
         namespace_rec.update(values.copy())
         namespace_rec.save(session=session)
     except db_exc.DBDuplicateEntry:
-        LOG.debug("Invalid update. It would result in a duplicate"
-                  " metadata definition namespace with the same name of %s",
-                  values['namespace'])
+        msg = ("Invalid update. It would result in a duplicate"
+               " metadata definition namespace with the same name of %s"
+               % values['namespace'])
+        LOG.debug(msg)
         emsg = (_("Invalid update. It would result in a duplicate"
                   " metadata definition namespace with the same name of %s")
                 % values['namespace'])
         raise exc.MetadefDuplicateNamespace(emsg)
 
-    return namespace_rec.to_dict()
+    return namespace_rec.as_dict()
 
 
-def delete(context, session, name):
+def delete(context, name, session):
     """Raise if not found, has references or not visible"""
 
-    namespace_rec = _get_by_name(context, session, name)
+    namespace_rec = _get_by_name(context, name, session)
     try:
         session.delete(namespace_rec)
         session.flush()
     except db_exc.DBError as e:
         if isinstance(e.inner_exception, sa_exc.IntegrityError):
-            LOG.debug("Metadata definition namespace=%s not deleted. "
-                      "Other records still refer to it.", name)
+            msg = ("Metadata definition namespace=%s not deleted."
+                   " Other records still refer to it." % name)
+            LOG.debug(msg)
             raise exc.MetadefIntegrityError(
                 record_type='namespace', record_name=name)
         else:
-            raise
+            raise e
 
-    return namespace_rec.to_dict()
+    return namespace_rec.as_dict()
 
 
-def delete_cascade(context, session, name):
+def delete_cascade(context, name, session):
     """Raise if not found, has references or not visible"""
 
-    namespace_rec = _get_by_name(context, session, name)
-    try:
-        metadef_api.tag.delete_namespace_content(
-            context, session, namespace_rec.id)
-        metadef_api.object.delete_namespace_content(
-            context, session, namespace_rec.id)
-        metadef_api.property.delete_namespace_content(
-            context, session, namespace_rec.id)
-        metadef_api.resource_type_association.delete_namespace_content(
-            context, session, namespace_rec.id)
-        session.delete(namespace_rec)
-        session.flush()
-    except db_exc.DBError as e:
-        if isinstance(e.inner_exception, sa_exc.IntegrityError):
-            LOG.debug("Metadata definition namespace=%s not deleted. "
-                      "Other records still refer to it.", name)
-            raise exc.MetadefIntegrityError(
-                record_type='namespace', record_name=name)
-        else:
-            raise
+    namespace_rec = _get_by_name(context, name, session)
+    with session.begin():
+        try:
+            metadef_api.object.delete_namespace_content(
+                context, namespace_rec.id, session)
+            metadef_api.property.delete_namespace_content(
+                context, namespace_rec.id, session)
+            metadef_api.resource_type_association.delete_namespace_content(
+                context, namespace_rec.id, session)
+            session.delete(namespace_rec)
+            session.flush()
+        except db_exc.DBError as e:
+            if isinstance(e.inner_exception, sa_exc.IntegrityError):
+                msg = ("Metadata definition namespace=%s not deleted."
+                       " Other records still refer to it." % name)
+                LOG.debug(msg)
+                raise exc.MetadefIntegrityError(
+                    record_type='namespace', record_name=name)
+            else:
+                raise e
 
-    return namespace_rec.to_dict()
+    return namespace_rec.as_dict()
