@@ -13,8 +13,7 @@
 #    under the License.
 
 
-from oslo_db import exception as db_exc
-from oslo_log import log as logging
+from oslo.db import exception as db_exc
 from sqlalchemy import func
 import sqlalchemy.orm as sa_orm
 
@@ -22,20 +21,22 @@ from glance.common import exception as exc
 from glance.db.sqlalchemy.metadef_api import namespace as namespace_api
 import glance.db.sqlalchemy.metadef_api.utils as metadef_utils
 from glance.db.sqlalchemy import models_metadef as models
-from glance.i18n import _
+from glance import i18n
+import glance.openstack.common.log as os_logging
 
-LOG = logging.getLogger(__name__)
+LOG = os_logging.getLogger(__name__)
+_LW = i18n._LW
 
 
 def _get(context, object_id, session):
     try:
-        query = session.query(models.MetadefObject).filter_by(id=object_id)
+        query = session.query(models.MetadefObject)\
+            .filter_by(id=object_id)
         metadef_object = query.one()
     except sa_orm.exc.NoResultFound:
-        msg = (_("Metadata definition object not found for id=%s")
-               % object_id)
-        LOG.warning(msg)
-        raise exc.MetadefObjectNotFound(msg)
+        LOG.warn(_LW("Metadata definition object not found for id %s",
+                     object_id))
+        raise exc.MetadefRecordNotFound(record_type='object', id=object_id)
 
     return metadef_object
 
@@ -43,13 +44,14 @@ def _get(context, object_id, session):
 def _get_by_name(context, namespace_name, name, session):
     namespace = namespace_api.get(context, namespace_name, session)
     try:
-        query = session.query(models.MetadefObject).filter_by(
-            name=name, namespace_id=namespace['id'])
+        query = session.query(models.MetadefObject)\
+            .filter_by(name=name, namespace_id=namespace['id'])
         metadef_object = query.one()
     except sa_orm.exc.NoResultFound:
-        LOG.debug("The metadata definition object with name=%(name)s"
-                  " was not found in namespace=%(namespace_name)s.",
-                  {'name': name, 'namespace_name': namespace_name})
+        msg = ("The metadata definition object with name=%(name)s"
+               " was not found in namespace=%(namespace_name)s."
+               % {'name': name, 'namespace_name': namespace_name})
+        LOG.debug(msg)
         raise exc.MetadefObjectNotFound(object_name=name,
                                         namespace_name=namespace_name)
 
@@ -58,13 +60,13 @@ def _get_by_name(context, namespace_name, name, session):
 
 def get_all(context, namespace_name, session):
     namespace = namespace_api.get(context, namespace_name, session)
-    query = session.query(models.MetadefObject).filter_by(
-        namespace_id=namespace['id'])
+    query = session.query(models.MetadefObject)\
+        .filter_by(namespace_id=namespace['id'])
     md_objects = query.all()
 
     md_objects_list = []
     for obj in md_objects:
-        md_objects_list.append(obj.to_dict())
+        md_objects_list.append(obj.as_dict())
     return md_objects_list
 
 
@@ -78,20 +80,21 @@ def create(context, namespace_name, values, session):
     try:
         md_object.save(session=session)
     except db_exc.DBDuplicateEntry:
-        LOG.debug("A metadata definition object with name=%(name)s"
-                  " in namespace=%(namespace_name)s already exists.",
-                  {'name': md_object.name,
-                   'namespace_name': namespace_name})
+        msg = ("A metadata definition object with name=%(name)s"
+               " in namespace=%(namespace_name)s already exists."
+               % {'name': md_object.name,
+                  'namespace_name': namespace_name})
+        LOG.debug(msg)
         raise exc.MetadefDuplicateObject(
             object_name=md_object.name, namespace_name=namespace_name)
 
-    return md_object.to_dict()
+    return md_object.as_dict()
 
 
 def get(context, namespace_name, name, session):
     md_object = _get_by_name(context, namespace_name, name, session)
 
-    return md_object.to_dict()
+    return md_object.as_dict()
 
 
 def update(context, namespace_name, object_id, values, session):
@@ -105,17 +108,18 @@ def update(context, namespace_name, object_id, values, session):
         md_object.update(values.copy())
         md_object.save(session=session)
     except db_exc.DBDuplicateEntry:
-        LOG.debug("Invalid update. It would result in a duplicate"
-                  " metadata definition object with same name=%(name)s"
-                  " in namespace=%(namespace_name)s.",
-                  {'name': md_object.name, 'namespace_name': namespace_name})
+        msg = ("Invalid update. It would result in a duplicate"
+               " metadata definition object with same name=%(name)s"
+               " in namespace=%(namespace_name)s."
+               % {'name': md_object.name, 'namespace_name': namespace_name})
+        LOG.debug(msg)
         emsg = (_("Invalid update. It would result in a duplicate"
                   " metadata definition object with the same name=%(name)s"
                   " in namespace=%(namespace_name)s.")
                 % {'name': md_object.name, 'namespace_name': namespace_name})
         raise exc.MetadefDuplicateObject(emsg)
 
-    return md_object.to_dict()
+    return md_object.as_dict()
 
 
 def delete(context, namespace_name, object_name, session):
@@ -125,15 +129,15 @@ def delete(context, namespace_name, object_name, session):
     session.delete(md_object)
     session.flush()
 
-    return md_object.to_dict()
+    return md_object.as_dict()
 
 
 def delete_namespace_content(context, namespace_id, session):
     """Use this def only if the ns for the id has been verified as visible"""
 
     count = 0
-    query = session.query(models.MetadefObject).filter_by(
-        namespace_id=namespace_id)
+    query = session.query(models.MetadefObject)\
+        .filter_by(namespace_id=namespace_id)
     count = query.delete(synchronize_session='fetch')
     return count
 
@@ -147,6 +151,6 @@ def count(context, namespace_name, session):
     """Get the count of objects for a namespace, raise if ns not found"""
     namespace = namespace_api.get(context, namespace_name, session)
 
-    query = session.query(func.count(models.MetadefObject.id)).filter_by(
-        namespace_id=namespace['id'])
+    query = session.query(func.count(models.MetadefObject.id))\
+        .filter_by(namespace_id=namespace['id'])
     return query.scalar()
