@@ -17,9 +17,12 @@ import six.moves.urllib.parse as urlparse
 import sqlalchemy
 
 from glance.common import exception
+from glance.common import utils
+from glance.openstack.common import gettextutils
 import glance.openstack.common.log as logging
 
 LOG = logging.getLogger(__name__)
+_LE = gettextutils._LE
 
 
 def upgrade(migrate_engine):
@@ -55,10 +58,11 @@ def migrate_location_credentials(migrate_engine, to_quoted):
                         .where(images_table.c.id == image['id'])\
                         .values(location=fixed_uri).execute()
         except exception.BadStoreUri as e:
-            err_msg = _("Invalid store uri for image: %(image_id)s. "
-                        "Details: %(reason)s") % {'image_id': image.id,
-                                                  'reason': unicode(e)}
-            LOG.exception(err_msg)
+            reason = utils.exception_to_str(e)
+            msg = _LE("Invalid store uri for image: %(image_id)s. "
+                      "Details: %(reason)s") % {'image_id': image.id,
+                                                'reason': reason}
+            LOG.exception(msg)
             raise
 
 
