@@ -24,12 +24,15 @@ from glance.common import exception
 from glance.common import utils
 from glance.common import wsgi
 import glance.db
+from glance.openstack.common import gettextutils
 import glance.openstack.common.log as logging
 from glance.openstack.common import strutils
 from glance.openstack.common import timeutils
 
 
 LOG = logging.getLogger(__name__)
+_LE = gettextutils._LE
+_LI = gettextutils._LI
 
 CONF = cfg.CONF
 
@@ -71,7 +74,10 @@ def _normalize_image_location_for_db(image_data):
     for l in locations:
         location_data_dict[l] = {}
     for l in location_data:
-        location_data_dict[l['url']] = l['metadata']
+        location_data_dict[l['url']] = {'metadata': l['metadata'],
+                                        'status': l['status'],
+                                        # Note(zhiyan): New location has no ID.
+                                        'id': l['id'] if 'id' in l else None}
 
     # NOTE(jbresnah) preserve original order.  tests assume original order,
     # should that be defined functionality
@@ -79,8 +85,21 @@ def _normalize_image_location_for_db(image_data):
     for ld in location_data:
         if ld['url'] not in ordered_keys:
             ordered_keys.append(ld['url'])
-    location_data = [{'url': l, 'metadata': location_data_dict[l]}
-                     for l in ordered_keys]
+
+    location_data = []
+    for loc in ordered_keys:
+        data = location_data_dict[loc]
+        if data:
+            location_data.append({'url': loc,
+                                  'metadata': data['metadata'],
+                                  'status': data['status'],
+                                  'id': data['id']})
+        else:
+            location_data.append({'url': loc,
+                                  'metadata': {},
+                                  'status': 'active',
+                                  'id': None})
+
     image_data['locations'] = location_data
     return image_data
 
@@ -102,17 +121,17 @@ class Controller(object):
             return self.db_api.image_get_all(context, filters=filters,
                                              **params)
         except exception.NotFound:
-            LOG.info(_("Invalid marker. Image %(id)s could not be "
-                       "found.") % {'id': params.get('marker')})
+            LOG.info(_LI("Invalid marker. Image %(id)s could not be "
+                         "found.") % {'id': params.get('marker')})
             msg = _("Invalid marker. Image could not be found.")
             raise exc.HTTPBadRequest(explanation=msg)
         except exception.Forbidden:
-            LOG.info(_("Access denied to image %(id)s but returning "
-                       "'not found'") % {'id': params.get('marker')})
+            LOG.info(_LI("Access denied to image %(id)s but returning "
+                         "'not found'") % {'id': params.get('marker')})
             msg = _("Invalid marker. Image could not be found.")
             raise exc.HTTPBadRequest(explanation=msg)
         except Exception:
-            LOG.exception(_("Unable to get images"))
+            LOG.exception(_LE("Unable to get images"))
             raise
 
     def index(self, req):
@@ -144,7 +163,7 @@ class Controller(object):
                 result[field] = image[field]
             results.append(result)
 
-        LOG.info(_("Returning image list"))
+        LOG.debug("Returning image list")
         return dict(images=results)
 
     def detail(self, req):
@@ -162,7 +181,7 @@ class Controller(object):
 
         images = self._get_images(req.context, **params)
         image_dicts = [make_image_dict(i) for i in images]
-        LOG.info(_("Returning detailed image list"))
+        LOG.debug("Returning detailed image list")
         return dict(images=image_dicts)
 
     def _get_query_params(self, req):
@@ -316,20 +335,21 @@ class Controller(object):
         """Return data about the given image id."""
         try:
             image = self.db_api.image_get(req.context, id)
-            msg = _("Successfully retrieved image %(id)s")
-            LOG.info(msg % {'id': id})
+            msg = "Successfully retrieved image %(id)s" % {'id': id}
+            LOG.debug(msg)
         except exception.NotFound:
-            msg = _("Image %(id)s not found")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Image %(id)s not found") % {'id': id}
+            LOG.info(msg)
             raise exc.HTTPNotFound()
         except exception.Forbidden:
             # If it's private and doesn't belong to them, don't let on
             # that it exists
-            msg = _("Access denied to image %(id)s but returning 'not found'")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Access denied to image %(id)s but returning"
+                      " 'not found'") % {'id': id}
+            LOG.info(msg)
             raise exc.HTTPNotFound()
         except Exception:
-            LOG.exception(_("Unable to show image %s"), id)
+            LOG.exception(_LE("Unable to show image %s") % id)
             raise
 
         return dict(image=make_image_dict(image))
@@ -346,25 +366,26 @@ class Controller(object):
         """
         try:
             deleted_image = self.db_api.image_destroy(req.context, id)
-            msg = _("Successfully deleted image %(id)s")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Successfully deleted image %(id)s") % {'id': id}
+            LOG.info(msg)
             return dict(image=make_image_dict(deleted_image))
         except exception.ForbiddenPublicImage:
-            msg = _("Delete denied for public image %(id)s")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Delete denied for public image %(id)s") % {'id': id}
+            LOG.info(msg)
             raise exc.HTTPForbidden()
         except exception.Forbidden:
             # If it's private and doesn't belong to them, don't let on
             # that it exists
-            msg = _("Access denied to image %(id)s but returning 'not found'")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Access denied to image %(id)s but returning"
+                      " 'not found'") % {'id': id}
+            LOG.info(msg)
             return exc.HTTPNotFound()
         except exception.NotFound:
-            msg = _("Image %(id)s not found")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Image %(id)s not found") % {'id': id}
+            LOG.info(msg)
             return exc.HTTPNotFound()
         except Exception:
-            LOG.exception(_("Unable to delete image %s"), id)
+            LOG.exception(_LE("Unable to delete image %s") % id)
             raise
 
     @utils.mutating
@@ -389,9 +410,9 @@ class Controller(object):
 
         image_id = image_data.get('id')
         if image_id and not utils.is_uuid_like(image_id):
-            msg = _("Rejecting image creation request for invalid image "
-                    "id '%(bad_id)s'")
-            LOG.info(msg % {'bad_id': image_id})
+            msg = _LI("Rejecting image creation request for invalid image "
+                      "id '%(bad_id)s'") % {'bad_id': image_id}
+            LOG.info(msg)
             msg = _("Invalid image id format")
             return exc.HTTPBadRequest(explanation=msg)
 
@@ -402,20 +423,21 @@ class Controller(object):
             image_data = _normalize_image_location_for_db(image_data)
             image_data = self.db_api.image_create(req.context, image_data)
             image_data = dict(image=make_image_dict(image_data))
-            msg = _("Successfully created image %(id)s") % image_data['image']
+            msg = (_LI("Successfully created image %(id)s") %
+                   image_data['image'])
             LOG.info(msg)
             return image_data
         except exception.Duplicate:
             msg = _("Image with identifier %s already exists!") % image_id
-            LOG.error(msg)
+            LOG.warn(msg)
             return exc.HTTPConflict(msg)
         except exception.Invalid as e:
             msg = (_("Failed to add image metadata. "
-                     "Got error: %(e)s") % {'e': e})
+                     "Got error: %s") % utils.exception_to_str(e))
             LOG.error(msg)
             return exc.HTTPBadRequest(msg)
         except Exception:
-            LOG.exception(_("Unable to create image %s"), image_id)
+            LOG.exception(_LE("Unable to create image %s"), image_id)
             raise
 
     @utils.mutating
@@ -455,49 +477,51 @@ class Controller(object):
                                                      purge_props=purge_props,
                                                      from_state=from_state)
 
-            msg = _("Updating metadata for image %(id)s")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Updating metadata for image %(id)s") % {'id': id}
+            LOG.info(msg)
             return dict(image=make_image_dict(updated_image))
         except exception.Invalid as e:
             msg = (_("Failed to update image metadata. "
-                     "Got error: %(e)s") % {'e': e})
+                     "Got error: %s") % utils.exception_to_str(e))
             LOG.error(msg)
             return exc.HTTPBadRequest(msg)
         except exception.NotFound:
-            msg = _("Image %(id)s not found")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Image %(id)s not found") % {'id': id}
+            LOG.info(msg)
             raise exc.HTTPNotFound(body='Image not found',
                                    request=req,
                                    content_type='text/plain')
         except exception.ForbiddenPublicImage:
-            msg = _("Update denied for public image %(id)s")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Update denied for public image %(id)s") % {'id': id}
+            LOG.info(msg)
             raise exc.HTTPForbidden()
         except exception.Forbidden:
             # If it's private and doesn't belong to them, don't let on
             # that it exists
-            msg = _("Access denied to image %(id)s but returning 'not found'")
-            LOG.info(msg % {'id': id})
+            msg = _LI("Access denied to image %(id)s but returning"
+                      " 'not found'") % {'id': id}
+            LOG.info(msg)
             raise exc.HTTPNotFound(body='Image not found',
                                    request=req,
                                    content_type='text/plain')
         except exception.Conflict as e:
-            LOG.info(unicode(e))
+            LOG.info(utils.exception_to_str(e))
             raise exc.HTTPConflict(body='Image operation conflicts',
                                    request=req,
                                    content_type='text/plain')
         except Exception:
-            LOG.exception(_("Unable to update image %s"), id)
+            LOG.exception(_LE("Unable to update image %s") % id)
             raise
 
 
 def _limit_locations(image):
     locations = image.pop('locations', [])
-    try:
-        image['location'] = locations[0]['url']
-    except IndexError:
-        image['location'] = None
     image['location_data'] = locations
+    image['location'] = None
+    for loc in locations:
+        if loc['status'] == 'active':
+            image['location'] = loc['url']
+            break
 
 
 def make_image_dict(image):
