@@ -20,9 +20,7 @@ import webob
 import glance.api.common
 from glance.common import config
 from glance.common import exception
-from glance.common import wsgi
 from glance.tests import utils as test_utils
-from glance.tests.unit import base
 
 
 class SimpleIterator(object):
@@ -56,7 +54,7 @@ class TestSizeCheckedIter(testtools.TestCase):
         resp = self._get_webob_response()
         meta = self._get_image_metadata()
         checked_image = glance.api.common.size_checked_iter(
-                resp, meta, 4, ['AB', 'CD'], None)
+            resp, meta, 4, ['AB', 'CD'], None)
 
         self.assertEqual('AB', checked_image.next())
         self.assertEqual('CD', checked_image.next())
@@ -66,7 +64,7 @@ class TestSizeCheckedIter(testtools.TestCase):
         resp = self._get_webob_response()
         meta = self._get_image_metadata()
         checked_image = glance.api.common.size_checked_iter(
-                resp, meta, 3, ['AB', 'C'], None)
+            resp, meta, 3, ['AB', 'C'], None)
 
         self.assertEqual('AB', checked_image.next())
         self.assertEqual('C', checked_image.next())
@@ -76,7 +74,7 @@ class TestSizeCheckedIter(testtools.TestCase):
         resp = self._get_webob_response()
         meta = self._get_image_metadata()
         checked_image = glance.api.common.size_checked_iter(
-                resp, meta, 6, ['AB', '', 'CDE', 'F'], None)
+            resp, meta, 6, ['AB', '', 'CDE', 'F'], None)
 
         self.assertEqual('AB', checked_image.next())
         self.assertEqual('', checked_image.next())
@@ -89,7 +87,7 @@ class TestSizeCheckedIter(testtools.TestCase):
         resp = self._get_webob_response()
         meta = self._get_image_metadata()
         checked_image = glance.api.common.size_checked_iter(
-                resp, meta, 4, ['AB', 'CD', 'EF'], None)
+            resp, meta, 4, ['AB', 'CD', 'EF'], None)
 
         self.assertEqual('AB', checked_image.next())
         self.assertEqual('CD', checked_image.next())
@@ -144,5 +142,5 @@ class TestMalformedRequest(test_utils.BaseTestCase):
         """Test Glance redirects /v# to /v#/ with correct Location header"""
         req = webob.Request.blank('/v1.1')
         res = req.get_response(self.api)
-        self.assertEquals(res.status_int, webob.exc.HTTPFound.code)
+        self.assertEqual(res.status_int, webob.exc.HTTPFound.code)
         self.assertEqual('http://localhost/v1/', res.location)
