@@ -17,20 +17,16 @@ import os
 import shutil
 
 import fixtures
+import glance_store as store
+from glance_store import location
 from oslo.config import cfg
+from oslo.db import options
 
 from glance.openstack.common import jsonutils
-from glance import store
-from glance.store import location
-from glance.store import sheepdog
-from glance.store import vmware_datastore
 from glance.tests import stubs
 from glance.tests import utils as test_utils
 
 CONF = cfg.CONF
-CONF.import_opt('filesystem_store_datadir', 'glance.store.filesystem')
-CONF.import_opt('connection', 'glance.openstack.common.db.sqlalchemy.session',
-                group='database')
 
 
 class StoreClearingUnitTest(test_utils.BaseTestCase):
@@ -43,14 +39,15 @@ class StoreClearingUnitTest(test_utils.BaseTestCase):
         self._create_stores()
         self.addCleanup(setattr, location, 'SCHEME_TO_CLS_MAP', dict())
 
-    def _create_stores(self):
+    def _create_stores(self, passing_config=True):
         """Create known stores. Mock out sheepdog's subprocess dependency
         on collie.
+
+        :param passing_config: making store driver passes basic configurations.
+        :returns: the number of how many store drivers been loaded.
         """
-        self.stubs.Set(sheepdog.Store, 'configure_add', lambda x: None)
-        self.stubs.Set(vmware_datastore.Store, 'configure', lambda x: None)
-        self.stubs.Set(vmware_datastore.Store, 'configure_add', lambda x: None)
-        store.create_stores()
+        store.register_opts(CONF)
+        store.create_stores(CONF)
 
 
 class IsolatedUnitTest(StoreClearingUnitTest):
@@ -65,14 +62,19 @@ class IsolatedUnitTest(StoreClearingUnitTest):
         super(IsolatedUnitTest, self).setUp()
         self.test_dir = self.useFixture(fixtures.TempDir()).path
         policy_file = self._copy_data_file('policy.json', self.test_dir)
-        self.config(connection='sqlite://',
-                    group='database')
+        options.set_defaults(CONF, connection='sqlite://',
+                             sqlite_db='glance.sqlite')
+
         self.config(verbose=False,
                     debug=False,
-                    default_store='filesystem',
-                    filesystem_store_datadir=os.path.join(self.test_dir),
                     policy_file=policy_file,
                     lock_path=os.path.join(self.test_dir))
+
+        self.config(default_store='filesystem',
+                    filesystem_store_datadir=os.path.join(self.test_dir),
+                    group="glance_store")
+
+        store.create_stores()
         stubs.stub_out_registry_and_store_server(self.stubs,
                                                  self.test_dir,
                                                  registry=self.registry)
