@@ -40,7 +40,7 @@ class TestContextMiddleware(base.IsolatedUnitTest):
     def test_header_parsing(self):
         req = self._build_request()
         self._build_middleware().process_request(req)
-        self.assertEqual(req.context.auth_tok, 'token1')
+        self.assertEqual(req.context.auth_token, 'token1')
         self.assertEqual(req.context.user, 'user1')
         self.assertEqual(req.context.tenant, 'tenant1')
         self.assertEqual(req.context.roles, ['role1', 'role2'])
@@ -92,7 +92,7 @@ class TestContextMiddleware(base.IsolatedUnitTest):
         self.config(allow_anonymous_access=True)
         middleware = self._build_middleware()
         middleware.process_request(req)
-        self.assertIsNone(req.context.auth_tok)
+        self.assertIsNone(req.context.auth_token)
         self.assertIsNone(req.context.user)
         self.assertIsNone(req.context.tenant)
         self.assertEqual(req.context.roles, [])
@@ -124,7 +124,7 @@ class TestUnauthenticatedContextMiddleware(base.IsolatedUnitTest):
         middleware = context.UnauthenticatedContextMiddleware(None)
         req = webob.Request.blank('/')
         middleware.process_request(req)
-        self.assertIsNone(req.context.auth_tok)
+        self.assertIsNone(req.context.auth_token)
         self.assertIsNone(req.context.user)
         self.assertIsNone(req.context.tenant)
         self.assertEqual(req.context.roles, [])
