@@ -15,13 +15,13 @@
 
 import fixtures
 import mock
+from oslo.db.sqlalchemy import migration
 import testtools
 
-import glance
 from glance.cmd import manage
 from glance.db import migration as db_migration
 from glance.db.sqlalchemy import api as db_api
-from glance.openstack.common.db.sqlalchemy import migration
+from glance.db.sqlalchemy import metadata as db_metadata
 
 
 class TestManageBase(testtools.TestCase):
@@ -32,7 +32,6 @@ class TestManageBase(testtools.TestCase):
         def clear_conf():
             manage.CONF.reset()
             manage.CONF.unregister_opt(manage.command_opt)
-            manage.CONF.db_enforce_mysql_charset = True
         self.addCleanup(clear_conf)
 
         self.patcher = mock.patch('glance.db.sqlalchemy.api.get_engine')
@@ -47,169 +46,175 @@ class TestManageBase(testtools.TestCase):
 
 class TestLegacyManage(TestManageBase):
 
-    def test_legacy_db_version(self):
-        migration.db_version = mock.Mock()
+    @mock.patch.object(migration, 'db_version')
+    def test_legacy_db_version(self, db_version):
         self._main_test_helper(['glance.cmd.manage', 'db_version'],
-                               glance.openstack.common.db.sqlalchemy.
                                migration.db_version,
                                db_api.get_engine(),
                                db_migration.MIGRATE_REPO_PATH, 0)
 
-    def test_legacy_db_sync(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_legacy_db_sync(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db_sync'],
-                               glance.openstack.common.db.sqlalchemy.
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, None,
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, None)
 
-    def test_legacy_db_upgrade(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_legacy_db_upgrade(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db_upgrade'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, None,
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, None)
 
-    def test_legacy_db_version_control(self):
-        migration.db_version_control = mock.Mock()
+    @mock.patch.object(migration, 'db_version_control')
+    def test_legacy_db_version_control(self, db_version_control):
         self._main_test_helper(['glance.cmd.manage', 'db_version_control'],
                                migration.db_version_control,
                                db_api.get_engine(),
                                db_migration.MIGRATE_REPO_PATH, None)
 
-    def test_legacy_db_sync_version(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_legacy_db_sync_version(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db_sync', '20'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, '20')
 
-    def test_legacy_db_upgrade_version(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_legacy_db_upgrade_version(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db_upgrade', '20'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, '20')
 
-    def test_legacy_db_downgrade_version(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_legacy_db_downgrade_version(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db_downgrade', '20'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, '20')
 
-    def test_legacy_db_sync_version_without_sanity_check(self):
-        migration.db_sync = mock.Mock()
-        manage.CONF.db_enforce_mysql_charset = False
-        self._main_test_helper(['glance.cmd.manage', 'db_sync', '20'],
-                               migration.db_sync,
-                               db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=False)
+    def test_db_metadefs_unload(self):
+        db_metadata.db_unload_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db_unload_metadefs'],
+                               db_metadata.db_unload_metadefs,
+                               db_api.get_engine())
 
-    def test_legacy_db_upgrade_version_without_sanity_check(self):
-        migration.db_sync = mock.Mock()
-        manage.CONF.db_enforce_mysql_charset = False
-        self._main_test_helper(['glance.cmd.manage', 'db_upgrade', '40'],
-                               migration.db_sync,
+    def test_db_metadefs_load(self):
+        db_metadata.db_load_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db_load_metadefs'],
+                               db_metadata.db_load_metadefs,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '40',
-                               sanity_check=False)
+                               None)
 
-    def test_legacy_db_downgrade_version_without_sanity_check(self):
-        migration.db_sync = mock.Mock()
-        manage.CONF.db_enforce_mysql_charset = False
-        self._main_test_helper(['glance.cmd.manage', 'db_downgrade', '20'],
-                               migration.db_sync,
+    def test_db_metadefs_load_with_specified_path(self):
+        db_metadata.db_load_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db_load_metadefs',
+                                '/mock/'],
+                               db_metadata.db_load_metadefs,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=False)
+                               '/mock/')
+
+    def test_db_metadefs_export(self):
+        db_metadata.db_export_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db_export_metadefs'],
+                               db_metadata.db_export_metadefs,
+                               db_api.get_engine(),
+                               None)
+
+    def test_db_metadefs_export_with_specified_path(self):
+        db_metadata.db_export_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db_export_metadefs',
+                               '/mock/'],
+                               db_metadata.db_export_metadefs,
+                               db_api.get_engine(),
+                               '/mock/')
 
 
 class TestManage(TestManageBase):
 
-    def test_db_version(self):
-        migration.db_version = mock.Mock()
+    @mock.patch.object(migration, 'db_version')
+    def test_db_version(self, db_version):
         self._main_test_helper(['glance.cmd.manage', 'db', 'version'],
                                migration.db_version,
                                db_api.get_engine(),
                                db_migration.MIGRATE_REPO_PATH, 0)
 
-    def test_db_sync(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_db_sync(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db', 'sync'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, None,
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, None)
 
-    def test_db_upgrade(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_db_upgrade(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db', 'upgrade'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, None,
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, None)
 
-    def test_db_version_control(self):
-        migration.db_version_control = mock.Mock()
+    @mock.patch.object(migration, 'db_version_control')
+    def test_db_version_control(self, db_version_control):
         self._main_test_helper(['glance.cmd.manage', 'db', 'version_control'],
                                migration.db_version_control,
                                db_api.get_engine(),
                                db_migration.MIGRATE_REPO_PATH, None)
 
-    def test_db_sync_version(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_db_sync_version(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db', 'sync', '20'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, '20')
 
-    def test_db_upgrade_version(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_db_upgrade_version(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db', 'upgrade', '20'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, '20')
 
-    def test_db_downgrade_version(self):
-        migration.db_sync = mock.Mock()
+    @mock.patch.object(migration, 'db_sync')
+    def test_db_downgrade_version(self, db_sync):
         self._main_test_helper(['glance.cmd.manage', 'db', 'downgrade', '20'],
                                migration.db_sync,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=True)
+                               db_migration.MIGRATE_REPO_PATH, '20')
 
-    def test_db_sync_version_without_sanity_check(self):
-        migration.db_sync = mock.Mock()
-        manage.CONF.db_enforce_mysql_charset = False
-        self._main_test_helper(['glance.cmd.manage', 'db', 'sync', '20'],
-                               migration.db_sync,
-                               db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, u'20',
-                               sanity_check=False)
+    def test_db_metadefs_unload(self):
+        db_metadata.db_unload_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db', 'unload_metadefs'],
+                               db_metadata.db_unload_metadefs,
+                               db_api.get_engine())
 
-    def test_db_upgrade_version_without_sanity_check(self):
-        migration.db_sync = mock.Mock()
-        manage.CONF.db_enforce_mysql_charset = False
-        self._main_test_helper(['glance.cmd.manage', 'db', 'upgrade', '40'],
-                               migration.db_sync,
+    def test_db_metadefs_load(self):
+        db_metadata.db_load_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db', 'load_metadefs'],
+                               db_metadata.db_load_metadefs,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '40',
-                               sanity_check=False)
+                               None)
 
-    def test_db_downgrade_version_without_sanity_check(self):
-        migration.db_sync = mock.Mock()
-        manage.CONF.db_enforce_mysql_charset = False
-        self._main_test_helper(['glance.cmd.manage', 'db', 'downgrade', '20'],
-                               migration.db_sync,
+    def test_db_metadefs_load_with_specified_path(self):
+        db_metadata.db_load_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db', 'load_metadefs',
+                                '--path', '/mock/'],
+                               db_metadata.db_load_metadefs,
                                db_api.get_engine(),
-                               db_migration.MIGRATE_REPO_PATH, '20',
-                               sanity_check=False)
+                               '/mock/')
+
+    def test_db_metadefs_export(self):
+        db_metadata.db_export_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db', 'export_metadefs'],
+                               db_metadata.db_export_metadefs,
+                               db_api.get_engine(),
+                               None)
+
+    def test_db_metadefs_export_with_specified_path(self):
+        db_metadata.db_export_metadefs = mock.Mock()
+        self._main_test_helper(['glance.cmd.manage', 'db', 'export_metadefs',
+                                '--path', '/mock/'],
+                               db_metadata.db_export_metadefs,
+                               db_api.get_engine(),
+                               '/mock/')
