@@ -38,6 +38,7 @@ from migrate.versioning.repository import Repository
 from oslo.config import cfg
 import six.moves.urllib.parse as urlparse
 from six.moves import xrange
+from six import text_type
 import sqlalchemy
 
 from glance.common import crypt
@@ -139,7 +140,8 @@ class TestMigrations(test_utils.BaseTestCase):
 
         # Load test databases from the config file. Only do this
         # once. No need to re-run this on each test...
-        LOG.debug('config_path is %s' % TestMigrations.CONFIG_FILE_PATH)
+        LOG.debug('config_path is %s',
+                  text_type(TestMigrations.CONFIG_FILE_PATH))
         if os.path.exists(TestMigrations.CONFIG_FILE_PATH):
             cp = ConfigParser.RawConfigParser()
             try:
@@ -332,7 +334,7 @@ class TestMigrations(test_utils.BaseTestCase):
                               init_version + 1)
         self.assertEqual(init_version + 1, db_version())
 
-        LOG.debug('latest version is %s' % TestMigrations.REPOSITORY.latest)
+        LOG.debug('latest version is %s', TestMigrations.REPOSITORY.latest)
 
         for version in xrange(init_version + 2,
                               TestMigrations.REPOSITORY.latest + 1):
@@ -958,7 +960,7 @@ class TestMigrations(test_utils.BaseTestCase):
 
     def _check_020(self, engine, data):
         images = get_table(engine, 'images')
-        self.assertFalse('location' in images.c)
+        self.assertNotIn('location', images.c)
 
     def _pre_upgrade_026(self, engine):
         image_locations = get_table(engine, 'image_locations')
@@ -994,7 +996,7 @@ class TestMigrations(test_utils.BaseTestCase):
         r = list(results)
         self.assertEqual(len(r), 1)
         self.assertEqual(r[0]['value'], 'file:///some/place/onthe/fs')
-        self.assertTrue('meta_data' in r[0])
+        self.assertIn('meta_data', r[0])
         x = pickle.loads(r[0]['meta_data'])
         self.assertEqual(x, {})
 
@@ -1302,7 +1304,7 @@ class TestMigrations(test_utils.BaseTestCase):
                 .where(image_locations.c.image_id == image_id).execute()
             r = list(results)
             self.assertEqual(len(r), 1)
-            self.assertTrue('status' in r[0])
+            self.assertIn('status', r[0])
             self.assertEqual(r[0]['status'], status_list[idx])
 
     def _post_downgrade_033(self, engine):
@@ -1336,3 +1338,209 @@ class TestMigrations(test_utils.BaseTestCase):
     def _post_downgrade_034(self, engine):
         images = get_table(engine, 'images')
         self.assertNotIn('virtual_size', images.c)
+
+    def _pre_upgrade_035(self, engine):
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'metadef_namespaces')
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'metadef_properties')
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'metadef_objects')
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'metadef_resource_types')
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine,
+                          'metadef_namespace_resource_types')
+
+    def _check_035(self, engine, data):
+        meta = sqlalchemy.MetaData()
+        meta.bind = engine
+
+        # metadef_namespaces
+        table = sqlalchemy.Table("metadef_namespaces", meta, autoload=True)
+        index_namespace = ('ix_namespaces_namespace', ['namespace'])
+        index_data = [(idx.name, idx.columns.keys())
+                      for idx in table.indexes]
+        self.assertIn(index_namespace, index_data)
+
+        expected_cols = [u'id',
+                         u'namespace',
+                         u'display_name',
+                         u'description',
+                         u'visibility',
+                         u'protected',
+                         u'owner',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+        # metadef_objects
+        table = sqlalchemy.Table("metadef_objects", meta, autoload=True)
+        index_namespace_id_name = (
+            'ix_objects_namespace_id_name', ['namespace_id', 'name'])
+        index_data = [(idx.name, idx.columns.keys())
+                      for idx in table.indexes]
+        self.assertIn(index_namespace_id_name, index_data)
+
+        expected_cols = [u'id',
+                         u'namespace_id',
+                         u'name',
+                         u'description',
+                         u'required',
+                         u'schema',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+         # metadef_properties
+        table = sqlalchemy.Table("metadef_properties", meta, autoload=True)
+        index_namespace_id_name = (
+            'ix_metadef_properties_namespace_id_name',
+            ['namespace_id', 'name'])
+        index_data = [(idx.name, idx.columns.keys())
+                      for idx in table.indexes]
+        self.assertIn(index_namespace_id_name, index_data)
+
+        expected_cols = [u'id',
+                         u'namespace_id',
+                         u'name',
+                         u'schema',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+         # metadef_resource_types
+        table = sqlalchemy.Table(
+            "metadef_resource_types", meta, autoload=True)
+        index_resource_types_name = (
+            'ix_metadef_resource_types_name', ['name'])
+        index_data = [(idx.name, idx.columns.keys())
+                      for idx in table.indexes]
+        self.assertIn(index_resource_types_name, index_data)
+
+        expected_cols = [u'id',
+                         u'name',
+                         u'protected',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+         # metadef_namespace_resource_types
+        table = sqlalchemy.Table(
+            "metadef_namespace_resource_types", meta, autoload=True)
+        index_ns_res_types_res_type_id_ns_id = (
+            'ix_metadef_ns_res_types_res_type_id_ns_id',
+            ['resource_type_id', 'namespace_id'])
+        index_data = [(idx.name, idx.columns.keys())
+                      for idx in table.indexes]
+        self.assertIn(index_ns_res_types_res_type_id_ns_id, index_data)
+
+        expected_cols = [u'resource_type_id',
+                         u'namespace_id',
+                         u'properties_target',
+                         u'prefix',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+    def _post_downgrade_035(self, engine):
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'metadef_namespaces')
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'metadef_properties')
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'metadef_objects')
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'metadef_resource_types')
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine,
+                          'metadef_namespace_resource_types')
+
+    def _pre_upgrade_036(self, engine):
+        meta = sqlalchemy.MetaData()
+        meta.bind = engine
+
+        # metadef_objects
+        table = sqlalchemy.Table("metadef_objects", meta, autoload=True)
+        expected_cols = [u'id',
+                         u'namespace_id',
+                         u'name',
+                         u'description',
+                         u'required',
+                         u'schema',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+        # metadef_properties
+        table = sqlalchemy.Table("metadef_properties", meta, autoload=True)
+        expected_cols = [u'id',
+                         u'namespace_id',
+                         u'name',
+                         u'schema',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+    def _check_036(self, engine, data):
+        meta = sqlalchemy.MetaData()
+        meta.bind = engine
+
+        # metadef_objects
+        table = sqlalchemy.Table("metadef_objects", meta, autoload=True)
+        expected_cols = [u'id',
+                         u'namespace_id',
+                         u'name',
+                         u'description',
+                         u'required',
+                         u'json_schema',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+        # metadef_properties
+        table = sqlalchemy.Table("metadef_properties", meta, autoload=True)
+        expected_cols = [u'id',
+                         u'namespace_id',
+                         u'name',
+                         u'json_schema',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+    def _post_downgrade_036(self, engine):
+        meta = sqlalchemy.MetaData()
+        meta.bind = engine
+
+        # metadef_objects
+        table = sqlalchemy.Table("metadef_objects", meta, autoload=True)
+        expected_cols = [u'id',
+                         u'namespace_id',
+                         u'name',
+                         u'description',
+                         u'required',
+                         u'schema',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
+
+        # metadef_properties
+        table = sqlalchemy.Table("metadef_properties", meta, autoload=True)
+        expected_cols = [u'id',
+                         u'namespace_id',
+                         u'name',
+                         u'schema',
+                         u'created_at',
+                         u'updated_at']
+        col_data = [col.name for col in table.columns]
+        self.assertEqual(expected_cols, col_data)
